@@ -44,7 +44,8 @@ DEFAULT_EDC_INSTALLED_APPS = [
     "edc_pharmacy.apps.AppConfig",
     "edc_pdutils.apps.AppConfig",
     "edc_protocol.apps.AppConfig",
-    "edc_protocol_violation.apps.AppConfig",
+    "edc_protocol_incident.apps.AppConfig",
+    "edc_protocol_violation.apps.AppConfig",  # to be removed
     "edc_prn.apps.AppConfig",
     "edc_randomization.apps.AppConfig",
     "edc_registration.apps.AppConfig",
